==> ev_framework-0.0.4.tar.gz: lib/Elves/Forms/Ev_Form_Item.dart <==
import '../System/Ev_Lang.dart';
import 'package:flutter/material.dart';
import 'Ev_Form.dart';

const  Map<String, String> TextEdit_error_email = {'1': 'Invalid Email', '2': '電郵地址不正確'};
const  Map<String, String> TextEdit_error_mobile = {'1': 'Invalid Tel', '2': '電話號碼不正碓'};
const  Map<String, String> TextEdit_error_confirm_password = {'1': 'Confirm password not correct ', '2': '確認密碼不正確'};
const  Map<String, String> TextEdit_error_password = {'1': 'Must be 8-20 characters', '2': '必需為 8 - 20 個字元'};

class Ev_From_text extends StatefulWidget {
  var key_value;
  var label;
  var default_value;
  var password;
  var check_empty;
  var check_email;
  var check_password;
  var check_mobile;
  var check_vaild_func;  // if valid return emply string or return error_message
  var has_line;
  var placeholder;
  var max_size;
  var keyborad_type;
  var max_line;
  var eye_on;

  Ev_Form form;
  Ev_From_text({this.form,this.key_value,this.label="",this.default_value = "",this.eye_on = false,this.check_mobile=false, this.check_empty = true,this.max_line=2,this.check_email = false,this.password = false,this.check_password = false,this.check_vaild_func,this.has_line = false ,this.placeholder = "",this.max_size = 100,this.keyborad_type = TextInputType.text}) ;

  @override
  _PIA_From_itemState createState()=> _PIA_From_itemState();
}

class _PIA_From_itemState extends State<Ev_From_text> {
   Widget error_widget = Container();
   var password_on;

  void initState() {
    print("build form init " + widget.key_value);
    widget.form.init(widget.key_value,check_valid);
    widget.form.set(widget.key_value,widget.default_value);
    password_on = widget.password;
    super.initState();
  }


  check_widget_init()
  {   print("form reset :" + widget.form.reset.toString());
      if(widget.form.reset == true) {
          widget.form.get_controller(widget.key_value).text_color = widget.form.label_Color;
          widget.form.set(widget.key_value,widget.default_value);
        }
   }

  @override
  Widget build(BuildContext context) {
    Ev_Form_Controller Form = widget.form.get_controller(widget.key_value);
    check_widget_init();

    return Container(
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.only(top:10.0),
                  child: Text(widget.label,style: TextStyle(color:Form.text_color, fontSize: widget.form.label_Size)),
                ),
                SizedBox(width: 20),
                Expanded( child:
                   TextField(textAlign: TextAlign.right,
                    minLines: 1 ,
                    maxLines: widget.max_line,
                    style: TextStyle(fontSize: widget.form.input_Size,color:widget.form.input_Color),
                    obscureText: password_on,
                    decoration: new InputDecoration(
                      border: InputBorder.none,
                      hintText: widget.placeholder,
                      hintStyle: TextStyle(fontSize: 13,color:Colors.grey.withOpacity(0.7)),
                      counterText: "",
                    ),
                    controller: Form.Controller,
                    maxLength: widget.max_size,
                    keyboardType: widget.keyborad_type,
                  )

                ),

                Container( height: 45,
                  child: (widget.eye_on) ?  IconButton(icon:Icon(Icons.remove_red_eye),color:Colors.grey,
                    onPressed: (){
                      setState(() {
                        password_on = password_on ? false : true;
                     });
                  },) : Container(height: 45,),
                )

              ]),
          (widget.has_line) ? Container(color:widget.form.line_color,height: 1,) : Container(),
          error_widget,
          SizedBox(height: 15,)
        ],
      ),
    );
   }


  bool check_valid()
  {  final value = widget.form.get(widget.key_value).toString();
     var output = true;

     error_widget = Container();
     widget.form.get_controller(widget.key_value).text_color = widget.form.label_Color;

    if(widget.check_empty == true && value == "") {
       setState(() {
         widget.form.get_controller(widget.key_value).text_color  = Colors.red;
       });
       return  false;
     }

   if(widget.check_email == true && !RegExp(r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+").hasMatch(value))
    {  setState(() {
         error_widget = Container(width:double.infinity,child: Text(TextEdit_error_email[Ev_Lang.lang_id],style:TextStyle(color: Colors.red,fontSize: 12),textAlign: TextAlign.right,));
       });
      return false;
     }

   if(widget.check_password == true) {
    if (value.length < 8 || value.length > 20) {
      setState(() {
        error_widget = Container(width:double.infinity,child: Text(TextEdit_error_password[Ev_Lang.lang_id],style:TextStyle(color: Colors.red,fontSize: 12),textAlign: TextAlign.right,));
      });
      return false;
    }
  }

  if(widget.check_mobile == true && value!="")
    {  var m = int.parse(value,onError: (e){ return  0;});
        if(m<20000000 || m>99900000){
           setState(() {
             error_widget = Container(width:double.infinity,child: Text(TextEdit_error_mobile[Ev_Lang.lang_id],style:TextStyle(color: Colors.red,fontSize: 12),textAlign: TextAlign.right,));
           });
         return false;
       }
    }

  if(widget.check_vaild_func != null)
  {   var error_message = widget.check_vaild_func();
      if(error_message != "") {
        setState(() {
          error_widget = Container(width:double.infinity,child: Text(error_message,style: TextStyle(color: Colors.red, fontSize: 12),textAlign: TextAlign.right,));
        });
        return  false;
     }
  }

  setState(() {});

  return output;
  }


}

==> ev_framework-2.0.4.tar.gz: lib/Elves/Forms/Ev_Form_Item.dart <==
import '../System/Ev_Lang.dart';
import 'package:flutter/material.dart';
import 'Ev_Form.dart';

const  Map<String, String> TextEdit_error_email = {'1': 'Invalid Email', '2': '電郵地址不正確'};
const  Map<String, String> TextEdit_error_mobile = {'1': 'Invalid Tel', '2': '電話號碼不正碓'};
const  Map<String, String> TextEdit_error_confirm_password = {'1': 'Confirm password not correct ', '2': '確認密碼不正確'};
const  Map<String, String> TextEdit_error_password = {'1': 'Must be 8-20 characters', '2': '必需為 8 - 20 個字元'};

class Ev_From_text extends StatefulWidget {
  var key_value;
  var label;
  var default_value;
  var password;
  var check_empty;
  var check_email;
  var check_password;
  var check_mobile;
  var check_vaild_func;  // if valid return emply string or return error_message
  var has_line;
  var placeholder;
  var max_size;
  var keyborad_type;
  var max_line;
  var eye_on;

  Ev_Form form;
  Ev_From_text({this.form,this.key_value,this.label="",this.default_value = "",this.eye_on = false,this.check_mobile=false, this.check_empty = true,this.max_line=2,this.check_email = false,this.password = false,this.check_password = false,this.check_vaild_func,this.has_line = false ,this.placeholder = "",this.max_size = 100,this.keyborad_type = TextInputType.text}) ;

  @override
  _PIA_From_itemState createState()=> _PIA_From_itemState();
}

class _PIA_From_itemState extends State<Ev_From_text> {
   Widget error_widget = Container();
   var password_on;

  void initState() {
    print("build form init " + widget.key_value);
    widget.form.init(widget.key_value,check_valid);
    widget.form.set(widget.key_value,widget.default_value);
    password_on = widget.password;
    super.initState();
  }


  check_widget_init()
  {   print("form reset :" + widget.form.reset.toString());
      if(widget.form.reset == true) {
          widget.form.get_controller(widget.key_value).text_color = widget.form.label_Color;
          widget.form.set(widget.key_value,widget.default_value);
        }
   }

  @override
  Widget build(BuildContext context) {
    Ev_Form_Controller Form = widget.form.get_controller(widget.key_value);
    check_widget_init();

    return Container(
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.only(top:10.0),
                  child: Text(widget.label,style: TextStyle(color:Form.text_color, fontSize: widget.form.label_Size)),
                ),
                SizedBox(width: 20),
                Expanded( child:
                   TextField(textAlign: TextAlign.right,
                    minLines: 1 ,
                    maxLines: widget.max_line,
                    style: TextStyle(fontSize: widget.form.input_Size,color:widget.form.input_Color),
                    obscureText: password_on,
                    decoration: new InputDecoration(
                      border: InputBorder.none,
                      hintText: widget.placeholder,
                      hintStyle: TextStyle(fontSize: 13,color:Colors.grey.withOpacity(0.7)),
                      counterText: "",
                    ),
                    controller: Form.Controller,
                    maxLength: widget.max_size,
                    keyboardType: widget.keyborad_type,
                  )

                ),

                Container( height: 45,
                  child: (widget.eye_on) ?  IconButton(icon:Icon(Icons.remove_red_eye),
                    color: (!password_on) ? widget.form.input_Color : widget.form.input_Color.withOpacity(0.2),
                    onPressed: (){
                      setState(() {
                        password_on = password_on ? false : true;
                     });
                  },) : Container(height: 45,),
                )

              ]),
          (widget.has_line) ? Container(color:widget.form.line_color,height: 1,) : Container(),
          error_widget,
          SizedBox(height: 15,)
        ],
      ),
    );
   }


  bool check_valid()
  {  final value = widget.form.get(widget.key_value).toString();
     var output = true;

     error_widget = Container();
     widget.form.get_controller(widget.key_value).text_color = widget.form.label_Color;

    if(widget.check_empty == true && value == "") {
       setState(() {
         widget.form.get_controller(widget.key_value).text_color  = Colors.red;
       });
       return  false;
     }

   if(widget.check_email == true && !RegExp(r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+").hasMatch(value))
    {  setState(() {
         error_widget = Container(width:double.infinity,child: Text(TextEdit_error_email[Ev_Lang.lang_id],style:TextStyle(color: Colors.red,fontSize: 12),textAlign: TextAlign.right,));
       });
      return false;
     }

   if(widget.check_password == true) {
    if (value.length < 8 || value.length > 20) {
      setState(() {
        error_widget = Container(width:double.infinity,child: Text(TextEdit_error_password[Ev_Lang.lang_id],style:TextStyle(color: Colors.red,fontSize: 12),textAlign: TextAlign.right,));
      });
      return false;
    }
  }

  if(widget.check_mobile == true && value!="")
    {  var m = int.parse(value,onError: (e){ return  0;});
        if(m<20000000 || m>99900000){
           setState(() {
             error_widget = Container(width:double.infinity,child: Text(TextEdit_error_mobile[Ev_Lang.lang_id],style:TextStyle(color: Colors.red,fontSize: 12),textAlign: TextAlign.right,));
           });
         return false;
       }
    }

  if(widget.check_vaild_func != null)
  {   var error_message = widget.check_vaild_func();
      if(error_message != "") {
        setState(() {
          error_widget = Container(width:double.infinity,child: Text(error_message,style: TextStyle(color: Colors.red, fontSize: 12),textAlign: TextAlign.right,));
        });
        return  false;
     }
  }

  setState(() {});

  return output;
  }


}
